<?php

declare(strict_types=1);

namespace FiloBlu\Rma\View\Element\Block;

use Magento\Framework\App\ObjectManager;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Store\Model\StoreManagerInterface;

/**
 *
 */
class RmaConfig implements ArgumentInterface
{

    /**
     * @var \Magento\Framework\Serialize\Serializer\Json
     */
    private $serializer;

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    private $storeManager;

    /**
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Framework\Serialize\Serializer\Json|null $serializer
     */
    public function __construct(StoreManagerInterface $storeManager, Json $serializer = null)
    {
        $this->serializer = $serializer ?: ObjectManager::getInstance()->get(Json::class);
        $this->storeManager = $storeManager;
    }

    /**
     * @return bool|string
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getSerializedConfig()
    {
        return $this->serializer->serialize($this->getConfig());
    }

    /**
     * Returns rma config
     *
     * @return array
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getConfig()
    {
        return [
            'baseUrl'      => $this->storeManager->getStore()->getBaseUrl(),
            'websiteId'    => $this->storeManager->getStore()->getWebsiteId(),
            'storeId'      => $this->storeManager->getStore()->getId(),
            'storeGroupId' => $this->storeManager->getStore()->getStoreGroupId()
        ];
    }

}